@@ -17,6 +17,9 @@
 # API元数据解析失败。
 FAILEDOPERATION_APIMETAPARSEFAILED = 'FailedOperation.ApiMetaParseFailed'
 
+# 调用TSF-APM服务获取配置列表失败
+FAILEDOPERATION_APMGETCONFIGSFAILED = 'FailedOperation.ApmGetConfigsFailed'
+
 # 创建应用，获取ES鉴权信息失败。
 FAILEDOPERATION_APPLICATIONCREATEESATUHERROR = 'FailedOperation.ApplicationCreateEsAtuhError'
 
@@ -26,6 +29,12 @@ FAILEDOPERATION_APPLICATIONQUERYFAILED = 'FailedOperation.ApplicationQueryFailed
 # TSF应用性能管理调用tsf-dcfg模块失败
 FAILEDOPERATION_CALLTSFDCFGFAILED = 'FailedOperation.CallTsfDcfgFailed'
 
+# 调用CDI状态接口失败
+FAILEDOPERATION_CDISTATUSFAILED = 'FailedOperation.CdiStatusFailed'
+
+# 调用CDI状态返回数据异常
+FAILEDOPERATION_CDISTATUSINVALID = 'FailedOperation.CdiStatusInvalid'
+
 # TSF云API请求调用失败。
 FAILEDOPERATION_CLOUDAPIPROXYERROR = 'FailedOperation.CloudApiProxyError'
 
@@ -89,6 +98,12 @@ FAILEDOPERATION_CONTAINERGROUPKUBERNETESAPIINVOKEERROR = 'FailedOperation.Contai
 # 调用 kube-api-server 失败。
 FAILEDOPERATION_CONTAINERGROUPKUBERNETESCONNECTERROR = 'FailedOperation.ContainergroupKubernetesConnectError'
 
+# k8s集群可能处于异常状态，请删除或恢复k8s集群后，再进行操作
+FAILEDOPERATION_CONTAINERGROUPKUBERNETESTKECLUSTERABNORMAL = 'FailedOperation.ContainergroupKubernetesTkeClusterAbnormal'
+
+# 容器平台集群不可用，当前状态 %s
+FAILEDOPERATION_CPCLUSTERUNAVAILABLE = 'FailedOperation.CpClusterUnavailable'
+
 # 健康检查配置失败。
 FAILEDOPERATION_CVMCAEMASTERHEALTHCHECKCONFIGERROR = 'FailedOperation.CvmCaeMasterHealthCheckConfigError'
 
@@ -185,6 +200,12 @@ FAILEDOPERATION_SERVICEINSERTFAILED = 'FailedOperation.ServiceInsertFailed'
 # 服务查询失败。
 FAILEDOPERATION_SERVICEQUERYFAILED = 'FailedOperation.ServiceQueryFailed'
 
+# 可观测性支持依赖TAPM业务系统绑定
+FAILEDOPERATION_TAPMBINDREQUIRED = 'FailedOperation.TapmBindRequired'
+
+# 请使用TAPM提供的Otel探针
+FAILEDOPERATION_TAPMEXPIREDOTEL = 'FailedOperation.TapmExpiredOtel'
+
 # 任务创建异常。
 FAILEDOPERATION_TASKCREATEERROR = 'FailedOperation.TaskCreateError'
 
@@ -284,6 +305,9 @@ FAILEDOPERATION_TSFCMONITORCTSDBCLIENTREQUESTFAIL = 'FailedOperation.TsfCmonitor
 # TSF监控统计等待超时, 请稍后重试。
 FAILEDOPERATION_TSFMONITORWAITEDTIMEOUT = 'FailedOperation.TsfMonitorWaitedTimeout'
 
+# TSF服务管理通用异常。
+FAILEDOPERATION_TSFMSERROR = 'FailedOperation.TsfMsError'
+
 # 调用ms server失败。
 FAILEDOPERATION_TSFMSSERVERERROR = 'FailedOperation.TsfMsServerError'
 
@@ -314,6 +338,9 @@ INTERNALERROR_CAMROLEREQUESTERROR = 'InternalError.CamRoleRequestError'
 # 配置发布失败：无法连接配置中心服务器。
 INTERNALERROR_CANNOTCONNCONSULSERVER = 'InternalError.CanNotConnConsulServer'
 
+# 调用CDI状态接口返回数据异常
+INTERNALERROR_CDISTATUSDATAINVALID = 'InternalError.CdiStatusDataInvalid'
+
 # TSF云API请求调用失败。
 INTERNALERROR_CLOUDAPIPROXYERROR = 'InternalError.CloudApiProxyError'
 
@@ -428,6 +455,9 @@ INTERNALERROR_TSFMONITORDATEPARSEFAILED = 'InternalError.TsfMonitorDateParseFail
 # TSF监控统计内部异常, 请稍后重试。
 INTERNALERROR_TSFMONITORINTERNALERROR = 'InternalError.TsfMonitorInternalError'
 
+# TSF服务管理通用异常。
+INTERNALERROR_TSFMSERROR = 'InternalError.TsfMsError'
+
 # [%s]模块未处理异常。。
 INTERNALERROR_UNHANDLEDEXCEPTION = 'InternalError.UnhandledException'
 
@@ -758,6 +788,9 @@ INVALIDPARAMETERVALUE_CVMCAEMASTERTASKNOTEXIST = 'InvalidParameterValue.CvmCaeMa
 # 部署组不存在。
 INVALIDPARAMETERVALUE_DEPLOYGROUPNOTEXISTS = 'InvalidParameterValue.DeployGroupNotExists'
 
+# 重复数据集名。
+INVALIDPARAMETERVALUE_DUPLICATEPROGRAMNAME = 'InvalidParameterValue.DuplicateProgramName'
+
 # 文件配置项已经发布。
 INVALIDPARAMETERVALUE_FILECONFIGALREADYRELEASED = 'InvalidParameterValue.FileConfigAlreadyReleased'
 
@@ -863,6 +896,9 @@ INVALIDPARAMETERVALUE_INVALIDPARAMETER = 'InvalidParameterValue.InvalidParameter
 # 参数格式异常。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERFORMAT = 'InvalidParameterValue.InvalidParameterFormat'
 
+# 数据集名非法。
+INVALIDPARAMETERVALUE_INVALIDPROGRAMNAME = 'InvalidParameterValue.InvalidProgramName'
+
 # 已经绑定灰度规则，无法删除。
 INVALIDPARAMETERVALUE_LANEINFOALREADYUSED = 'InvalidParameterValue.LaneInfoAlreadyUsed'
 
@@ -887,6 +923,9 @@ INVALIDPARAMETERVALUE_LANEINFONOTEXISTENTRANCE = 'InvalidParameterValue.LaneInfo
 # 泳道备注不能超过200个字符。
 INVALIDPARAMETERVALUE_LANEINFOREMARKTOOLONG = 'InvalidParameterValue.LaneInfoRemarkTooLong'
 
+# 全链路灰度规则ID错误
+INVALIDPARAMETERVALUE_LANERULEIDINVALID = 'InvalidParameterValue.LaneRuleIdInvalid'
+
 # 全链路灰度规则中的泳道不存在。
 INVALIDPARAMETERVALUE_LANERULEINFONOTEXIST = 'InvalidParameterValue.LaneRuleInfoNotExist'
 
@@ -917,6 +956,15 @@ INVALIDPARAMETERVALUE_LANERULETAGNAMETOOLONG = 'InvalidParameterValue.LaneRuleTa
 # 全链路灰度规则必须设置至少一个标签。
 INVALIDPARAMETERVALUE_LANERULETAGNOTEMPTY = 'InvalidParameterValue.LaneRuleTagNotEmpty'
 
+# 全链路灰度规则逻辑关系错误
+INVALIDPARAMETERVALUE_LANERULETAGOPERATORINVALID = 'InvalidParameterValue.LaneRuleTagOperatorInvalid'
+
+# 全链路灰度规则逻辑关系不能为空
+INVALIDPARAMETERVALUE_LANERULETAGOPERATORNOTEMPTY = 'InvalidParameterValue.LaneRuleTagOperatorNotEmpty'
+
+# 全链路灰度规则标签值不能为空
+INVALIDPARAMETERVALUE_LANERULETAGVALUENOTEMPTY = 'InvalidParameterValue.LaneRuleTagValueNotEmpty'
+
 # 全链路灰度规则标签值不能超过128个字符。
 INVALIDPARAMETERVALUE_LANERULETAGVALUETOOLONG = 'InvalidParameterValue.LaneRuleTagValueTooLong'
 
@@ -938,6 +986,9 @@ INVALIDPARAMETERVALUE_NAMESPACENAMEINVALID = 'InvalidParameterValue.NamespaceNam
 # 无法获取命名空间。
 INVALIDPARAMETERVALUE_NAMESPACENOTEXISTS = 'InvalidParameterValue.NamespaceNotExists'
 
+# 数据集项不存在。
+INVALIDPARAMETERVALUE_PROGRAMITEMNOTEXISTS = 'InvalidParameterValue.ProgramItemNotExists'
+
 # 配置项已经发布，不允许删除。
 INVALIDPARAMETERVALUE_RELEASEDCONFIGCANNOTBEDELETED = 'InvalidParameterValue.ReleasedConfigCanNotBeDeleted'
 
